@@ -273,7 +273,12 @@ fn pep517(subcommand: Pep517Command) -> Result<()> {
             strip,
         } => {
             assert_eq!(build_options.interpreter.len(), 1);
-            let context = build_options.into_build_context(true, strip, false)?;
+            let context = build_options
+                .into_build_context()
+                .release(true)
+                .strip(strip)
+                .editable(false)
+                .build()?;
 
             // Since afaik all other PEP 517 backends also return linux tagged wheels, we do so too
             let tags = match context.bridge() {
@@ -298,7 +303,12 @@ fn pep517(subcommand: Pep517Command) -> Result<()> {
             strip,
             editable,
         } => {
-            let build_context = build_options.into_build_context(true, strip, editable)?;
+            let build_context = build_options
+                .into_build_context()
+                .release(true)
+                .strip(strip)
+                .editable(editable)
+                .build()?;
             let wheels = build_context.build_wheels()?;
             assert_eq!(wheels.len(), 1);
             println!("{}", wheels[0].0.to_str().unwrap());
@@ -311,11 +321,20 @@ fn pep517(subcommand: Pep517Command) -> Result<()> {
                 out: Some(sdist_directory),
                 cargo: CargoOptions {
                     manifest_path,
+                    // Enable all features to ensure all optional path dependencies are packaged
+                    // into source distribution
+                    all_features: true,
                     ..Default::default()
                 },
                 ..Default::default()
             };
-            let build_context = build_options.into_build_context(false, false, false)?;
+            let build_context = build_options
+                .into_build_context()
+                .release(false)
+                .strip(false)
+                .editable(false)
+                .sdist_only(true)
+                .build()?;
             let (path, _) = build_context
                 .build_source_distribution()?
                 .context("Failed to build source distribution, pyproject.toml not found")?;
@@ -358,7 +377,12 @@ fn run() -> Result<()> {
             strip,
             sdist,
         } => {
-            let build_context = build.into_build_context(release, strip, false)?;
+            let build_context = build
+                .into_build_context()
+                .release(release)
+                .strip(strip)
+                .editable(false)
+                .build()?;
             if sdist {
                 build_context
                     .build_source_distribution()?
@@ -375,7 +399,12 @@ fn run() -> Result<()> {
             no_strip,
             no_sdist,
         } => {
-            let build_context = build.into_build_context(!debug, !no_strip, false)?;
+            let build_context = build
+                .into_build_context()
+                .release(!debug)
+                .strip(!no_strip)
+                .editable(false)
+                .build()?;
 
             if !build_context.release {
                 eprintln!("⚠️  Warning: You're publishing debug wheels");
@@ -417,11 +446,20 @@ fn run() -> Result<()> {
                 out,
                 cargo: CargoOptions {
                     manifest_path,
+                    // Enable all features to ensure all optional path dependencies are packaged
+                    // into source distribution
+                    all_features: true,
                     ..Default::default()
                 },
                 ..Default::default()
             };
-            let build_context = build_options.into_build_context(false, false, false)?;
+            let build_context = build_options
+                .into_build_context()
+                .release(false)
+                .strip(false)
+                .editable(false)
+                .sdist_only(true)
+                .build()?;
             build_context
                 .build_source_distribution()?
                 .context("Failed to build source distribution, pyproject.toml not found")?;
